@@ -1,6 +1,7 @@
 
-from kbrainsdk.validation.common import get_payload
 import re
+from kbrainsdk.validation.common import get_payload, validate_required_parameters
+
 
 common_arguments = [
     "model_name", "model_type", 
@@ -46,9 +47,20 @@ def validate_aistudio_llms(req, endpoint_type):
 def validate_openai_llms(req, endpoint_type):    
     return validate_aistudio_llms(req, endpoint_type)
 
+def validate_stream_llm_output(req):
+    body = get_payload(req)
+    required_arguments = ["system_prompt", "messages", "streaming_args"]
+    validate_required_parameters(body, required_arguments)
+    system_prompt = body.get('system_prompt')
+    messages = body.get('messages')
+    streaming_args = body.get('streaming_args')
+
+    return system_prompt, messages, streaming_args
+
 def extract_integer(x, default):
     match = re.search(r'\d+', x)
     if match:
         return int(match.group())
     else:
-        return default
\ No newline at end of file
+        return default
+
