@@ -29,8 +29,9 @@ def validate_list_group_members(req):
     client_id = body.get('client_id')
     oauth_secret = body.get('oauth_secret')
     tenant_id = body.get('tenant_id')
+    continuation_token = body.get('continuation_token', None)
 
     if not validate_email(email):
         raise ValueError("Invalid email address")
     
-    return group_id, email, token, client_id, oauth_secret, tenant_id
\ No newline at end of file
+    return group_id, email, token, client_id, oauth_secret, tenant_id, continuation_token
\ No newline at end of file
